Documentation
¶
Rendered for windows/amd64
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrNoADS = errors.New("no alternate data stream found") ErrUnsupported = errors.New("file system does not support stream") )
Functions ¶
Types ¶
type FileADS ¶
FileADS handles alternate data streams of a file.
func GetFileADS ¶
GetFileADS returns ADS handler with a map of alternate data streams from the specified file.
func (*FileADS) CollectADS ¶
CollectADS collects name and size of alternate data streams of the file.
func (*FileADS) RemoveAllADS ¶
RemoveAllADS removes all alternate data streams from the file, leaving only the unnamed data stream, in which data are normally stored.
Click to show internal directories.
Click to hide internal directories.